%ifnarch %arm
%global mrpt_optflags %{optflags}
%else
%global mrpt_optflags $(echo "%{optflags}"| sed -e 's|O2|O1|')
%endif

Summary: Libraries and programs for mobile robot SLAM and navigation
Name: mrpt
Version: 1.0.2
Release: 9%{?dist}
License: BSD
Group: Development/Libraries
URL: http://www.mrpt.org/

#Source downloaded from:
#http://downloads.sourceforge.net/%{name}/MRPT-all/MRPT-1.0.0/%{name}-%{version}.tar.gz
# Then create_tarball_mrpt.sh was run to generate:
Source0: %{name}-%{version}-fedora.tar.xz
Source1: create_tarball_%{name}.sh
#Fixes build issues related to gcc 4.7
Patch0: mrpt-1.0.0-csparse.patch
# Get rid of -GNUCXX_PARALLEL flag when building with openmp
Patch1: mrpt-1.0.0-openmp.patch
# Patch to add missing inclusion guards to a header
Patch2: mrpt-1.0.0-eigen306.patch
# Build against system version of libfreenect
Patch3: mrpt-1.0.0-systemdeps.patch
# Fixes error: 
# error: the type 'dirs' is not supported for the entry tag within a navindex! Check your layout file!
Patch4: mrpt-0.9.6-doxygen.patch
# Fixes build issue related to include paths for pcl
Patch5: mrpt-1.0.2-pcl.patch
# Disable use of internal gtest
Patch6: mrpt-1.0.2-gtest.patch
BuildRequires: cmake
BuildRequires: wxGTK-devel, opencv-devel, freeglut-devel, lib3ds-devel
BuildRequires: boost-devel
BuildRequires: eigen3-static
BuildRequires: doxygen, ghostscript, graphviz
BuildRequires: tex(latex), tex(dvips)
%ifnarch s390 s390x
BuildRequires: libdc1394-devel
BuildRequires: pcl-devel
BuildRequires: tbb-devel
%endif
BuildRequires: libfreenect-devel
BuildRequires: libftdi-devel, libusb-devel
BuildRequires: libjpeg-turbo-devel
BuildRequires: libusbx-devel
BuildRequires: desktop-file-utils
BuildRequires: suitesparse-devel
BuildRequires: libphidget-devel
BuildRequires: perl-podlators

%description
The Mobile Robot Programming Toolkit (MRPT) is an extensive, cross-platform,
and open source C++ library aimed to help robotics researchers to design and
implement algorithms in the fields of Simultaneous Localization and Mapping 
(SLAM), computer vision, and motion planning (obstacle avoidance).

The libraries include classes for easily managing 3D(6D) geometry, 
probability density functions (pdfs) over many predefined variables (points 
and poses, landmarks, maps), Bayesian inference (Kalman filters, particle 
filters), image processing, path planning and obstacle avoidance, 3D 
visualization of all kind of maps (points, occupancy grids, landmarks,...), 
etc.
Gathering, manipulating and inspecting very large robotic datasets (Rawlogs)
efficiently is another goal of MRPT, supported by several classes and 
applications.

The MRPT is free software and is released under the GPL. 


# Subpackages "ann", "aria", "core", "hwdrivers", and "reactivenav" are provided
# in order to minimize dependencies of future packages that might depend on a
# subset only of all the MRPT libraries. The subpackage "libs" can be used as 
# a shortcut for all the libraries.

%package base
Summary: Mobile Robot Programming Toolkit - mrpt-base
Group: Development/Libraries
# These packages went away after release 0.9.6
Obsoletes: %{name}-graphs%{?_isa} < 1.0.0
Obsoletes: %{name}-graphslam%{?_isa} < 1.0.0
Obsoletes: %{name}-bayes%{?_isa} < 1.0.0
%description base
The Mobile Robot Programming Toolkit (MRPT) library mrpt-base


%package opengl
Summary: Mobile Robot Programming Toolkit - mrpt-opengl
Group: Development/Libraries
Requires: %{name}-base%{?_isa} = %{version}-%{release}
%description opengl
The Mobile Robot Programming Toolkit (MRPT) library mrpt-opengl

%package pbmap
Summary: Mobile Robot Programming Toolkit - mrpt-pbmap
Group: Development/Libraries
Requires: %{name}-base%{?_isa} = %{version}-%{release}
%description pbmap
The Mobile Robot Programming Toolkit (MRPT) library mrpt-pbmap

%package gui
Summary: Mobile Robot Programming Toolkit - mrpt-gui
Group: Development/Libraries
Requires: %{name}-opengl%{?_isa} = %{version}-%{release}
%description gui
The Mobile Robot Programming Toolkit (MRPT) library mrpt-gui


%package obs
Summary: Mobile Robot Programming Toolkit - mrpt-obs
Group: Development/Libraries
Requires: %{name}-opengl%{?_isa} = %{version}-%{release}
%description obs
The Mobile Robot Programming Toolkit (MRPT) library mrpt-obs


%package scanmatching
Summary: Mobile Robot Programming Toolkit - mrpt-scanmatching
Group: Development/Libraries
Requires: %{name}-base%{?_isa} = %{version}-%{release}
%description scanmatching
The Mobile Robot Programming Toolkit (MRPT) library mrpt-scanmatching


%package topography
Summary: Mobile Robot Programming Toolkit - mrpt-topography
Group: Development/Libraries
Requires: %{name}-scanmatching%{?_isa} = %{version}-%{release}
%description topography
The Mobile Robot Programming Toolkit (MRPT) library mrpt-topography


%package maps
Summary: Mobile Robot Programming Toolkit - mrpt-maps
Group: Development/Libraries
Requires: %{name}-obs%{?_isa} = %{version}-%{release}
%description maps
The Mobile Robot Programming Toolkit (MRPT) library mrpt-maps


%package vision
Summary: Mobile Robot Programming Toolkit - mrpt-vision
Group: Development/Libraries
Requires: %{name}-obs%{?_isa} = %{version}-%{release}
%description vision
The Mobile Robot Programming Toolkit (MRPT) library mrpt-vision


%package hwdrivers
Summary: Mobile Robot Programming Toolkit - mrpt-hwdrivers
Group: Development/Libraries
Requires: %{name}-obs%{?_isa} = %{version}-%{release}
Requires: %{name}-gui%{?_isa} = %{version}-%{release}
%description hwdrivers
The Mobile Robot Programming Toolkit (MRPT) library mrpt-hwdrivers


%package slam
Summary: Mobile Robot Programming Toolkit - mrpt-slam
Group: Development/Libraries
Requires: %{name}-pbmap%{?_isa} = %{version}-%{release}
Requires: %{name}-scanmatching%{?_isa} = %{version}-%{release}
Requires: %{name}-maps%{?_isa} = %{version}-%{release}
Requires: %{name}-vision%{?_isa} = %{version}-%{release}
%description slam
The Mobile Robot Programming Toolkit (MRPT) library mrpt-slam

%package kinematics
Summary: Mobile Robot Programming Toolkit - mrpt-kinematics
Group: Development/Libraries
Requires: %{name}-base%{?_isa} = %{version}-%{release}
%description kinematics
The Mobile Robot Programming Toolkit (MRPT) library mrpt-kinematics


%package reactivenav
Summary: Mobile Robot Programming Toolkit - mrpt-reactivenav
Group: Development/Libraries
Requires: %{name}-maps%{?_isa} = %{version}-%{release}
%description reactivenav
The Mobile Robot Programming Toolkit (MRPT) library mrpt-reactivenav


%package detectors
Summary: Mobile Robot Programming Toolkit - mrpt-detectors
Group: Development/Libraries
Requires: %{name}-maps%{?_isa} = %{version}-%{release}
Requires: %{name}-gui%{?_isa} = %{version}-%{release}
Requires: %{name}-vision%{?_isa} = %{version}-%{release}
%description detectors
The Mobile Robot Programming Toolkit (MRPT) library mrpt-detectors


%package hmtslam
Summary: Mobile Robot Programming Toolkit - mrpt-hmtslam
Group: Development/Libraries
Requires: %{name}-slam%{?_isa} = %{version}-%{release}
%description hmtslam
The Mobile Robot Programming Toolkit (MRPT) library mrpt-hmtslam


%package libs
Summary: Mobile Robot Programming Toolkit - All the libraries
Group: Development/Libraries
Requires: %{name}-detectors%{?_isa} = %{version}-%{release}
Requires: %{name}-reactivenav%{?_isa} = %{version}-%{release}
Requires: %{name}-hmtslam%{?_isa} = %{version}-%{release}
Requires: %{name}-slam%{?_isa} = %{version}-%{release}
Requires: %{name}-topography%{?_isa} = %{version}-%{release}
Requires: %{name}-gui%{?_isa} = %{version}-%{release}
Requires: %{name}-obs%{?_isa} = %{version}-%{release}
Requires: %{name}-maps%{?_isa} = %{version}-%{release}
Requires: %{name}-opengl%{?_isa} = %{version}-%{release}
Requires: %{name}-base%{?_isa} = %{version}-%{release}
Requires: %{name}-pbmap%{?_isa} = %{version}-%{release}
#Requires: %{name}-graphs = %{version}-%{release}
Requires: %{name}-kinematics%{?_isa} = %{version}-%{release}
%description libs
The Mobile Robot Programming Toolkit (MRPT) is an extensive, cross-platform,
and open source C++ library aimed to help robotics researchers to design and
implement algorithms in the fields of Simultaneous Localization and Mapping 
(SLAM), computer vision, and motion planning (obstacle avoidance).

This virtual package depends on all MRPT libraries.

%package apps
Summary: Mobile Robot Programming Toolkit - Console and GUI applications
Group: Applications/Engineering
Requires: %{name}-libs%{?_isa} = %{version}-%{release}
Requires: %{name}-2d-slam%{?_isa} = %{version}-%{release}
Requires: %{name}-camera-calibration%{?_isa} = %{version}-%{release}
Requires: %{name}-gridmap-navigation%{?_isa} = %{version}-%{release}
Requires: %{name}-navlog-viewer%{?_isa} = %{version}-%{release}
Requires: %{name}-rawlog-viewer%{?_isa} = %{version}-%{release}
Requires: %{name}-prrt-navigation%{?_isa} = %{version}-%{release}
Requires: %{name}-reactive-navigation%{?_isa} = %{version}-%{release}
Requires: %{name}-scene-viewer%{?_isa} = %{version}-%{release}

%description apps
The Mobile Robot Programming Toolkit (MRPT) is an extensive, cross-platform,
and open source C++ library aimed to help robotics researchers to design and
implement algorithms in the fields of Simultaneous Localization and Mapping 
(SLAM), computer vision, and motion planning (obstacle avoidance).

This package provides a set of console and GUI applications for manipulating 
datasets, particle filtering localization and SLAM, grabbing data from 
robotic sensors, etc.

# MRPT Apps
%package 2d-slam
Summary: Mobile Robot Progamming Toolkit 2D SLAM demo
Group: Applications/Engineering
Requires: %{name}-libs%{?_isa} = %{version}-%{release}
%description 2d-slam
2d-slam-demo is a GUI application which allows the user to run a
Extended Kalman Filter (EKF) implementation of range-bearing 2D SLAM in
step-by-step or continuous mode. Graphs are shown for the observations,
data association, etc.

%package camera-calibration
Summary: Mobile Robot Programming Toolkit Camera Calibration
Requires: %{name}-libs%{_isa} = %{version}-%{release}
%description camera-calibration
camera-calib-gui is a graphical application which allows the user to
select a sequence of images where a checkerboad (calibration pattern)
appears, then it computes the intrinsic and distortion parameters of
the camera, using the OpenCV implementation of Zhang's algorithm.

The sequence of images can be grabbed directly from a webcam, firewire
camera or any other video source.

%package gridmap-navigation
Summary: Mobile Robot Programming Toolkit Camera Calibration
Requires: %{name}-libs%{_isa} = %{version}-%{release}
%description gridmap-navigation
A GUI application for simulation of robot motion within a simulated
environment defined by an occupancy grid map. The program simulates
noisy odometry and laser measurements and generates a rawlog which can
then be used as the input of SLAM algorithms. A ground truth file is
also generated.

The robot is controlled with a joystick or the cursor arrow keys.

%package navlog-viewer
Summary: Mobile Robot Programming Toolkit Navigation Log Viewer
Requires: %{name}-libs%{_isa} = %{version}-%{release}
%description navlog-viewer
A GUI application for playing back the logs generated by MRPT programs such
as GridmapNavSimul. Navigaton logs are useful to debug the internal workings of
robot navigation algorithms, their internal decisions, etc.

%package prrt-navigation
Summary: Mobile Robot Programming Toolkit PRRT Navigation
Requires: %{name}-libs%{_isa} = %{version}-%{release}
%description prrt-navigation
A GUI program that allows experimenting with a
new robot navigation algorithm based on Rapidly-exploring Random Tree
(RTT) exploration using Parameterized Trajectory Generators (PTGs).

%package rawlog-viewer
Summary: Mobile Robot Programming Toolkit Raw Log Viewer
Requires: %{name}-libs%{_isa} = %{version}-%{release}
%description rawlog-viewer
A GUI viewer and editor of robotic datasets stored in the MRPT
rawlog format.

%package reactive-navigation
Summary: Mobile Robot Programming Toolkit Reactive Navigation
Requires: %{name}-libs%{_isa} = %{version}-%{release}
%description reactive-navigation
A program to demonstrate the usage of the mrpt reactivenav library. It
allow the user to set an arbitrary target and then simulate the robot
actions to try to reach the target.

The movements take into account the arbitrary shape of the robot, and a
set of kinematically-constrained trajectories.  

%package scene-viewer
Summary: Mobile Robot Programming Toolkit Scene Viewer
Requires: %{name}-libs%{_isa} = %{version}-%{release}
%description scene-viewer
A viewer for 3D scenes generated by MRPT applications in the
MRPT 3Dscene format: a (possibly gz-compressed) file where a
mrpt::opengl::COpenGLScene has been serialized.

%package devel
Summary: Mobile Robot Programming Toolkit - Development package
Group: Development/Libraries
Requires: %{name}-libs%{?_isa} = %{version}-%{release}
Requires: pkgconfig
Requires: suitesparse-devel
%description devel
The Mobile Robot Programming Toolkit (MRPT) is an extensive, cross-platform,
and open source C++ library aimed to help robotics researchers to design and
implement algorithms in the fields of Simultaneous Localization and Mapping 
(SLAM), computer vision, and motion planning (obstacle avoidance).

This package provides the headers and required files to build third-party 
applications that use MRPT libraries.


%package doc
Summary: Mobile Robot Programming Toolkit - Documentation
Group: Documentation
BuildArch: noarch
%description doc
The Mobile Robot Programming Toolkit (MRPT) is an extensive, cross-platform,
and open source C++ library aimed to help robotics researchers to design and
implement algorithms in the fields of Simultaneous Localization and Mapping 
(SLAM), computer vision, and motion planning (obstacle avoidance).

This package contains documentation, examples and the reference generated
with Doxygen.


%prep
%setup -q
%patch0 -p0 -b .csparse
%patch1 -p0 -b .openmp
%patch2 -p0 -b .eigen306
%patch3 -p0 -b .systemdeps
%patch4 -p0 -b .doxygen
%patch5 -p1 -b .pcl
%patch6 -p0 -b .gtest

# Fix encoding of the mrpt-book file
#gzip -d doc/mrpt-book.ps.gz
#iconv -f ISO8859-1 -t UTF-8 doc/mrpt-book.ps > mrpt-book.ps.conv
#mv -f mrpt-book.ps.conv doc/mrpt-book.ps
#gzip doc/mrpt-book.ps
rm -rf libs/opengl/src/{freeglut-2.4.0,glew,glext,lib3ds}
rm -rf libs/base/src/math/CSparse
rm -rf libs/base/include/mrpt/otherlibs/CSparse
rm -rf libs/base/src/utils/jpeglib
rm -rf libs/base/src/compress/zlib/

%build
# The flag CMAKE_MRPT_IS_RPM_PACKAGE disables global "-mtune=native"
mkdir build
cd build
export CFLAGS="%{mrpt_optflags}"
export CXXFLAGS="%{mrpt_optflags}"
export FCFLAGS="%{mrpt_optflags}"
export LDFLAGS="%{mrpt_optflags}"
cmake \
  -DCMAKE_C_FLAGS_RELEASE:STRING="-DNDEBUG" \
  -DCMAKE_CXX_FLAGS_RELEASE:STRING="-DNDEBUG" \
  -DCMAKE_Fortran_FLAGS_RELEASE:STRING="-DNDEBUG" \
  -DCMAKE_VERBOSE_MAKEFILE:BOOL=ON \
  -DCMAKE_INSTALL_PREFIX:PATH=/usr \
  -DINCLUDE_INSTALL_DIR:PATH=/usr/include \
  -DLIB_INSTALL_DIR:PATH=/usr/lib64 \
  -DSYSCONF_INSTALL_DIR:PATH=/etc \
  -DSHARE_INSTALL_PREFIX:PATH=/usr/share \
%if %{_lib} == "lib64" 
  -DLIB_SUFFIX=64 \
%endif 
  -DBUILD_SHARED_LIBS:BOOL=ON \
  -DCSPARSE_LIBRARY=%{_libdir}/libcxsparse.so \
  -DCMAKE_MRPT_IS_RPM_PACKAGE=1 \
  -DMRPT_ENABLE_LIBSTD_PARALLEL_MODE=ON \
  -DMRPT_ENABLE_PRECOMPILED_HDRS=OFF \
  -DMRPT_HAS_PHIDGET=ON \
  -DPHIDGET_ROOT_DIR=/usr \
  -DPHIDGET_LIB_DIR=%{_libdir} \
  -DMRPT_HAS_TBB=ON \
  -DTBB_LIB_DIR=%{_libdir} \
  -DMRPT_AUTODETECT_SSE=OFF \
  -DDISABLE_SSE4=ON \
  -DDISABLE_SSE3=ON \
%ifnarch x86_64
  -DDISABLE_SSE2=ON \
%endif
  -DBOOST_ROOT=/usr \
  -DBOOST_LIBRARYDIR=%{_libdir} \
  -DMRPT_OPTIMIZE_NATIVE=OFF \
  -DCMAKE_BUILD_TYPE=None \
  -DEIGEN_USE_EMBEDDED_VERSION=OFF \
  -DBUILD_KINECT_USE_FREENECT=ON \
  -DBUILD_ARIA=OFF \
  -DBUILD_XSENS=OFF \
  -DDISABLE_SIFT_HESS=ON \
  -DPCL_FIND_QUIETLY=OFF \
  -DBUILD_TESTING=OFF \
  ..

make VERBOSE=1 -j 3
#%{?_smp_mflags}
make documentation_html
make man_pages_all

%check
export LD_LIBRARY_PATH=$(pwd)/lib
make -C build test VERBOSE=1 ARGS="-VV" || echo "**Warning**: unit tests failed, check whether it was only due to SSE* stuff" 

%install
make -C build install DESTDIR=$RPM_BUILD_ROOT
# Validate .g files:
find ${RPM_BUILD_ROOT}%{_datadir}/applications/ -name "*.desktop" | xargs -I FIL desktop-file-validate FIL
rm -fr $RPM_BUILD_ROOT/%{_datadir}/mrpt-doc

%files base
%doc README COPYING
%{_libdir}/libmrpt-base.so.*
# This directory is empty here but contains files in other sub-packages 
#  depending on mrpt-base:
%dir %{_datadir}/mrpt
%{_datadir}/mime/packages/*.xml

%files opengl
%doc README COPYING
%{_libdir}/libmrpt-opengl.so.*

%files scanmatching
%doc README COPYING
%{_libdir}/libmrpt-scanmatching.so.*

%files pbmap
%doc README COPYING
%{_libdir}/libmrpt-pbmap.so.*

%files obs
%doc README COPYING
%{_libdir}/libmrpt-obs.so.*

%files gui
%doc README COPYING
%{_libdir}/libmrpt-gui.so.*

%files topography
%doc README COPYING
%{_libdir}/libmrpt-topography.so.*

%files maps
%doc README COPYING
%{_libdir}/libmrpt-maps.so.*

%files vision
%doc README COPYING
%{_libdir}/libmrpt-vision.so.*

%files hwdrivers
%doc README COPYING
%{_libdir}/libmrpt-hwdrivers.so.*

%files reactivenav
%doc README COPYING
%{_libdir}/libmrpt-reactivenav.so.*

%files detectors
%doc README COPYING
%{_libdir}/libmrpt-detectors.so.*

%files slam
%doc README COPYING
%{_libdir}/libmrpt-slam.so.*

%files kinematics
%doc README COPYING
%{_libdir}/libmrpt-kinematics.so.*

%files hmtslam
%doc README COPYING
%{_libdir}/libmrpt-hmtslam.so.*

%files apps
%doc README COPYING
%exclude %{_bindir}/2d-slam-demo
%exclude %{_bindir}/camera-calib
%exclude %{_bindir}/GridmapNavSimul
%exclude %{_bindir}/navlog-viewer
%exclude %{_bindir}/prrt-navigator-demo
%exclude %{_bindir}/RawLogViewer
%exclude %{_bindir}/ReactiveNavigationDemo
%exclude %{_bindir}/SceneViewer3D
%{_bindir}/*
%{_datadir}/pixmaps/*.ico
%{_datadir}/pixmaps/monoslam.xpm
# %{_datadir}/mrpt is owned by mrpt-base:
%{_datadir}/mrpt/config_files/
%{_datadir}/mrpt/datasets/
%exclude %{_mandir}/man1/2d-slam-demo.1.*
%exclude %{_mandir}/man1/camera-calib.1.*
%exclude %{_mandir}/man1/GridmapNavSimul.1.*
%exclude %{_mandir}/man1/navlog-viewer.1.*
%exclude %{_mandir}/man1/prrt-navigator-demo.1.*
%exclude %{_mandir}/man1/RawLogViewer.1.*
%exclude %{_mandir}/man1/ReactiveNavigationDemo.1.*
%exclude %{_mandir}/man1/SceneViewer3D.1.*
%{_mandir}/man1/*

%files 2d-slam
%{_datadir}/applications/2dslamdemo.desktop
%{_datadir}/pixmaps/2d-slam-demo.xpm
%{_bindir}/2d-slam-demo
%{_mandir}/man1/2d-slam-demo.1.*

%files camera-calibration
%{_datadir}/applications/cameracalibgui.desktop
%{_datadir}/pixmaps/cameracalibgui.xpm
%{_bindir}/camera-calib
%{_mandir}/man1/camera-calib.1.*

%files gridmap-navigation
%{_datadir}/applications/gridmapnavsimul.desktop
%{_datadir}/pixmaps/gridmapsimul.xpm
%{_bindir}/GridmapNavSimul
%{_mandir}/man1/GridmapNavSimul.1.*

%files navlog-viewer
%{_datadir}/applications/navlog-viewer.desktop
%{_datadir}/pixmaps/navlog-viewer.xpm
%{_bindir}/navlog-viewer
%{_mandir}/man1/navlog-viewer.1.*

%files prrt-navigation
%{_datadir}/applications/prrtnavigatordemo.desktop
%{_datadir}/pixmaps/reactivenav.xpm
%{_bindir}/prrt-navigator-demo
%{_mandir}/man1/prrt-navigator-demo.1.*

%files rawlog-viewer
%{_datadir}/applications/rawlogviewer.desktop
%{_datadir}/pixmaps/rawlogviewer.xpm
%{_bindir}/RawLogViewer
%{_mandir}/man1/RawLogViewer.1.*

%files reactive-navigation
%{_datadir}/applications/reactivenavdemo.desktop
%{_datadir}/pixmaps/reactivenav.xpm
%{_bindir}/ReactiveNavigationDemo
%{_mandir}/man1/ReactiveNavigationDemo.1.*

%files scene-viewer
%{_datadir}/applications/sceneviewer.desktop
%{_datadir}/pixmaps/sceneviewer.xpm
%{_bindir}/SceneViewer3D
%{_mandir}/man1/SceneViewer3D.1.*

%files devel
%doc README COPYING
%{_libdir}/*.so
%{_includedir}/mrpt
%{_libdir}/pkgconfig/*.pc
# %{_datadir}/mrpt is owned by mrpt-core:
%{_datadir}/mrpt/MRPTConfig.cmake

%files doc
%doc README COPYING
%doc doc/html

%files libs
%doc README COPYING

%post opengl -p /sbin/ldconfig
%postun opengl -p /sbin/ldconfig

%post gui -p /sbin/ldconfig
%postun gui -p /sbin/ldconfig

%post obs -p /sbin/ldconfig
%postun obs -p /sbin/ldconfig

%post scanmatching -p /sbin/ldconfig
%postun scanmatching -p /sbin/ldconfig

%post topography -p /sbin/ldconfig
%postun topography -p /sbin/ldconfig

%post maps -p /sbin/ldconfig
%postun maps -p /sbin/ldconfig

%post vision -p /sbin/ldconfig
%postun vision -p /sbin/ldconfig

%post hwdrivers -p /sbin/ldconfig
%postun hwdrivers -p /sbin/ldconfig

%post reactivenav -p /sbin/ldconfig
%postun reactivenav -p /sbin/ldconfig

%post detectors -p /sbin/ldconfig
%postun detectors -p /sbin/ldconfig

%post slam -p /sbin/ldconfig
%postun slam -p /sbin/ldconfig

%post hmtslam -p /sbin/ldconfig
%postun hmtslam -p /sbin/ldconfig

%post pbmap -p /sbin/ldconfig
%postun pbmap -p /sbin/ldconfig

%post kinematics -p /sbin/ldconfig
%postun kinematics -p /sbin/ldconfig

%post base
/sbin/ldconfig
update-mime-database %{_datadir}/mime &> /dev/null || :

%postun base
/sbin/ldconfig
update-mime-database %{_datadir}/mime &> /dev/null || :


%changelog
* Mon Sep 01 2014 Rich Mattes <richmattes@gmail.com> - 1.0.2-9
- Split apps into separate packages for appstream

* Fri Aug 22 2014 Jiri Kastner <jkastner /at/ redhat /dot/ com> - 1.0.2-8
- Rebuild for libreenect 0.5.0

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat May 24 2014 Petr Machata <pmachata@redhat.com> - 1.0.2-5
- Rebuild for boost 1.55.0

* Fri May 23 2014 David Tardon <dtardon@redhat.com> - 1.0.2-4
- rebuild for boost 1.55.0

* Sat May 03 2014 Rich Mattes <richmattes@gmail.com> - 1.0.2-3
- Rebuild for libfreenect

* Fri Dec 06 2013 Nils Philippsen <nils@redhat.com> - 1.0.2-2
- rebuild (suitesparse)

* Sun Sep 08 2013 Rich Mattes <richmattes@gmail.com> - 1.0.2-1
- Update to release 1.0.2
- Re-enable tbb on ARM

* Sun Aug  4 2013 Peter Robinson <pbrobinson@fedoraproject.org> 1.0.1-5
- Modernise SPEC
- exclude tbb build dep on ARM (not currently available)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jul 28 2013 Petr Machata <pmachata@redhat.com> - 1.0.1-3
- Rebuild for boost 1.54.0

* Sat Jun 29 2013 Rich Mattes <richmattes@gmail.com> - 1.0.1-2
- Compress tarball using xz (rhbz#979191)
- Change to require eigen3-static instead of -devel
- Rebuild for new eigen3 (rhbz#978971)

* Sun Jun 02 2013 Rich Mattes <richmattes@gmail.com> - 1.0.1-1
- Update to release 1.0.1

* Fri May 24 2013 Petr Machata <pmachata@redhat.com> - 1.0.0-3
- Rebuild for TBB memory barrier bug

* Tue Apr 16 2013 Rich Mattes <richmattes@gmail.com> - 1.0.0-2
- License changed to BSD for 1.0.0, updated spec license field to match

* Mon Apr 15 2013 Rich Mattes <richmattes@gmail.com> - 1.0.0-1
- Update to release 1.0.0

* Sat Feb 23 2013 Rich Mattes <richmattes@gmail.com> - 0.9.6-6
- Fixed doxygen layout file to work with new doxygen version
- Fixed bogus changelog dates
- Made doc subpackage noarch

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.9.6-6
- Rebuild for Boost-1.53.0

* Mon Jan 21 2013 Adam Tkac <atkac redhat com> - 0.9.6-5
- rebuild due to "jpeg8-ABI" feature drop

* Thu Jan 03 2013 Dan Horák <dan[at]danny.cz> - 0.9.6-4
- update BRs for s390(x)

* Sat Dec 22 2012 Rich Mattes <richmattes@gmail.com> - 0.9.6-3
- Rebuild for new flann

* Sat Nov 10 2012 Rich Mattes <richmattes@gmail.com> - 0.9.6-2
- Rebuild for new OpenCV

* Sun Aug 26 2012 Rich Mattes <richmattes@gmail.com> - 0.9.6-1
- Added dependency on suitesparse
- Fixed resolution of libphidget and tbb

* Sat Aug 25 2012 Rich Mattes <richmattes@gmail.com> - 0.9.6-1
- Updated to 0.9.6

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.5-0.6.20110917svn2662
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jul 14 2012 Rich Mattes <richmattes@gmail.com> - 0.9.5-0.5.20110917svn2662
- Rebuild for new OpenCV
- Fix for zlib 1.2.7
- Fix for gcc 4.7

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.5-0.4.20110917svn2662
- Rebuilt for c++ ABI breakage

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.5-0.3.20110917svn2662
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sun Oct 16 2011 Dan Horák <dan[at]danny.cz> - 0.9.5-0.2.20110917svn2662
- no FireWire on s390(x)

* Mon Sep 19 2011 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.9.5-0.1.20110917svn2662
- New 0.9.5 svn snapshot.

* Fri Sep 16 2011 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.9.5-0.1.20110916svn2655
- New 0.9.5 svn snapshot.

* Tue Aug 23 2011 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.9.5-0.1.20110823svn2634
- New 0.9.5 svn snapshot.

* Mon Jan 10 2011 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.9.4-0.1.20110110svn2383
- New 0.9.4 svn snapshot, with more secure unit tests for autobuilders.

* Mon Jan 10 2011 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.9.4-0.1.20110110svn2382
- Packaging of new upstream version 0.9.4 (svn snapshot)

* Mon Jan 10 2011 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.9.4-0.1.20110110svn2380
- Packaging of new upstream version 0.9.4 (svn snapshot)

* Sat Dec 25 2010 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.9.4-0.1.20101225svn2354
- Packaging of new upstream version 0.9.4 (svn snapshot)

* Wed Jul 14 2010 Dan Horák <dan@danny.cz> - 0.9.0-0.5
- rebuilt against wxGTK-2.8.11-2

* Sun Jul 4 2010 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.9.0-0.4
- Rebuild needed by new opencv.

* Sun Jun 6 2010 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.9.0-0.3
- Changed source tarball name numbering.

* Sat Jun 5 2010 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.9.0-0.2
- Fixed build against OpenCV.

* Fri Jun 4 2010 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.9.0-0.1
- Packaging of new upstream version 0.9.0.

* Sat Mar  6 2010 - Thomas Spura <tomspur@fedoraproject.org> 0.8.0-0.3.20100102svn1398
- rebuild as requested in
  http://lists.fedoraproject.org/pipermail/devel/2010-March/132519.html

* Fri Jan 22 2010 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.8.0-0.2.20100102svn1398
- Fixed dependencies in spec file.

* Thu Jan 21 2010 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.8.0-0.1.20100102svn1398
- Packaging of new upstream version 0.8.0.

* Tue Aug 18 2009 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.7.1-0.1.20090818svn1148
- Packaging of new upstream version 0.7.1, patched.

* Mon Aug 17 2009 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.7.1-0.1.20090817svn1147
- Packaging of new upstream version 0.7.1.

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-0.2.20090529svn1047
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Jul 14 2009 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.7.0-0.1.20090529svn1047
- Packaging of new upstream version 0.7.0.

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.5-0.4.20090213svn807
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Feb 19 2009 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.6.5-0.3.20090213svn807
- Fixed ownship of datadir/mrpt/config_files/ by two sub-packages.

* Fri Feb 13 2009 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.6.5-0.2.20090213svn807
- All applications are now in mrpt-apps.

* Fri Feb 13 2009 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.6.5-0.1.20090213
- New upstream sources.
- Individual packages created for each MRPT application.
- Removed unneeded dependencies from -devel package.
- Fixed "doc" package should own the mrpt-doc directory.
- Mime types moved to mrpt-core package.

* Sun Jan 18 2009 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.6.5-0.1.20090118svn746
- New upstream sources.
- Fixed license tag to "GPLv3+".
- Added "export LD_LIBRARY_PATH..." at "check" to allow the tests to work.
- Comments added explaining the split in subpackages.
- devel package depends on wxGTK-devel instead of wxGTK due to needed headers.
- datadir/mrpt is now owned by mrpt-core to avoid duplicated ownership.
- Several fixes to libmrpt.pc
- Added calls to "update-desktop-database" and "update-mime-database" in post/postun of mrpt-apps.
- Corrected texlive-latex dependency to enable compilation of doxygen formulas.

* Thu Jan 8 2009 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.6.4-2
- More verbose output in 'make test', and possibly fixed wrong compiler flag.
- Fixed ownership of the same file MRPTConfig.cmake in two subpackages.

* Sun Jan 4 2009 - Jose Luis Blanco <joseluisblancoc@gmail.com> 0.6.4-1
- Initial packaging for Fedora.

